.. _homogenization-homogenization_opt:

homogenization/homogenization_opt.py
====================================

**Description**

missing description!



:download:`source code </../sfepy/examples/homogenization/homogenization_opt.py>`

.. literalinclude:: /../sfepy/examples/homogenization/homogenization_opt.py

